@@ -478,6 +478,33 @@ def dispatch(host: CPanelEndpoint, args: List[str]) -> str:
 		elif cmd_is(cmd, "get mysql restriction"):
 			r = host.dump(lambda: uapi.Mysql.get_restrictions())
 
+		elif cmd_is(cmd, "create postgres user"):
+			r = host.check(lambda: uapi.Postgresql.create_user(name = args[3], password = args[4]))
+
+		elif cmd_is(cmd, "list postgres user"):
+			r = host.dump(lambda: uapi.Postgresql.list_users())
+
+		elif cmd_is(cmd, "rename postgres user"):
+			r = host.check(lambda: uapi.Postgresql.rename_user(oldname = args[3], newname = args[4], password = args[5]))
+
+		elif cmd_is(cmd, "set postgres password"):
+			r = host.check(lambda: uapi.Postgresql.set_password(user = args[3], password = args[4]))
+
+		elif cmd_is(cmd, "delete postgres user", "rm postgres user", "remove postgres user"):
+			r = host.check(lambda: uapi.Postgresql.delete_user(name = args[3]))
+
+		elif cmd_is(cmd, "create postgres database"):
+			r = host.check(lambda: uapi.Postgresql.create_database(name = args[3]))
+
+		elif cmd_is(cmd, "list postgres database"):
+			r = host.dump(lambda: uapi.Postgresql.list_databases())
+
+		elif cmd_is(cmd, "rename mysql database"):
+			r = host.check(lambda: uapi.Postgresql.rename_database(oldname = args[3], newname = args[4]))
+
+		elif cmd_is(cmd, "delete mysql database", "rm mysql database", "remove mysql database"):
+			r = host.check(lambda: uapi.Postgresql.delete_database(name = args[3]))
+
 		else:
 			die("unrecognized command, {}".format(cmd))
 
