@@ -14,7 +14,7 @@ extensions = []
 templates_path = []
 exclude_patterns = ['build', 'Thumbs.db', '.DS_Store']
 html_static_path = ['_static/']
-html_title = cpanel.__description__ + " (v" + cpanel.__version__ + ")"
+html_title = cpanel.__description__ + " (v0.21.1)"
 locale_dirs = ['locale/']
 gettext_compact = False
 html_sidebars = {
